@@ -3,7 +3,10 @@ from ._base import APIKeyClient as APIKeyClient
 from .specmanagerdb import Client as SMDBClient
 from .certronic import Client as CertronicClient
 from .exactian import Client as ExactianClient
-from .visma import Client as VismaClient
+from .visma import (
+    Client as VismaClient,
+    AsyncClient as VismaAsyncClient
+)
 from .specmanagerapi import (
     Client as SMAPIClient,
     EmployeeType as SMEmployeeType
