@@ -16,6 +16,18 @@ class Decorators:
             return method(client, *args, **kwargs)
         return wrapper
 
+    @staticmethod
+    def ensure_async_session(method: Callable) -> Callable:
+        async def wrapper(clt, *args, **kwargs) -> Optional[Any]:
+            if clt.session == None or getattr(clt.session, "closed", None):
+                raise ConnectionError(f"""
+                    Start a session with self.start_session() before of make a 
+                    request or use "with" expression like async with 
+                    {clt.__class__.__name__}(url=...) as client: ...
+                """)
+            return await method(clt, *args, **kwargs)
+        return wrapper
+
 
 def random_str(
     size: Optional[int] = 5,
