@@ -972,7 +972,7 @@ class Client(OAuthClient):
 
         # safety only
         if results.get('total') > 1:
-            raise ValueError("Más de un empleado con el mismo identificador.")
+            raise ValueError("More than one employee with the same identifier")
 
         # update employee
         if results.get('total') == 1:
@@ -1003,4 +1003,3 @@ class Client(OAuthClient):
 
         # save employee
         return self.save_element(**data)
-
