@@ -104,7 +104,7 @@ class Client:
         # return true for general propose
         return True
 
-    def run_import_lips(self, table: str, lips_name: str, _hash: str = None, \
+    def run_import_lips(self, table: str, lips_name: str, hash_: str = None, \
             source: str = 'spec-utils', downconf_table: str = 'AR_DOWNCONF', \
             **kwargs):
         """ Insert into AR_DOWN_CONF table so LIPS can import. """
@@ -116,7 +116,7 @@ class Client:
             'PARTIAL': True,
             'SOURCE': source,
             'LIPS': lips_name,
-            'HASH_CODE': _hash or token_hex(8),
+            'HASH_CODE': hash_ or token_hex(8),
             'END_TIME': None,
         }])
 
